@@ -11,6 +11,7 @@ user_pref("browser.reader.detectedFirstArticle", true);
 user_pref("browser.fixup.alternate.enabled", false);
 user_pref("browser.fixup.alternate.suffix", ".invalid");
 user_pref("browser.library.activity-stream.enabled", false);
+user_pref("browser.newtabpage.activity-stream.asrouter.disable-captive-portal-vpn-promo", true);
 user_pref("browser.newtabpage.activity-stream.feeds.snippets", false);
 user_pref("browser.newtab.preload", false);
 user_pref("browser.newtabpage.activity-stream.asrouter.userprefs.cfr.addons", false);
@@ -20,6 +21,8 @@ user_pref("browser.newtabpage.activity-stream.feeds.topsites", false);
 user_pref("browser.newtabpage.enabled", false);
 user_pref("browser.newtabpage.enhanced", false);
 user_pref("browser.newtabpage.introShown", true);
+user_pref("browser.privatebrowsing.promoEnabled", false);
+user_pref("browser.privatebrowsing.promoTitleEnabled, false);
 user_pref("browser.search.hiddenOneOffs", "Google,Amazon.com,Bing,DuckDuckGo,Wikipedia (en)");
 user_pref("browser.search.suggest.enabled", false);
 user_pref("browser.selfsupport.url", "");
@@ -28,6 +31,7 @@ user_pref("browser.shell.checkDefaultBrowser", false);
 user_pref("browser.startup.blankWindow", true);
 user_pref("browser.startup.homepage", "about:blank");
 user_pref("browser.toolbarbuttons.introduced.pocket-button", true);
+user_pref("browser.toolbars.bookmarks.2h2020", false);
 user_pref("browser.urlbar.trimURLs", false);
 user_pref("datareporting.healthreport.service.enabled", false);
 user_pref("datareporting.healthreport.uploadEnabled", false);
@@ -59,10 +63,12 @@ user_pref("network.http.referer.spoofSource", true);
 user_pref("network.predictor.enabled", false);
 user_pref("network.prefetch-next", false);
 user_pref("network.trr.mode", 0);
+user_pref("pdfjs.enablescripting", false);
 user_pref("privacy.donottrackheader.enabled", true);
 user_pref("privacy.donottrackheader.value", 1);
-user_pref("privacy.resistFingerprinting", true);
+user_pref("privacy.resistFingerprinting", false);
 user_pref("privacy.trackingprotection.enabled", true);
 user_pref("privacy.trackingprotection.introCount", 20);
 user_pref("privacy.trackingprotection.pbmode.enabled", true);
+user_pref("signon.includeOtherSubdomainsInLookup", false);
 user_pref("toolkit.telemetry.enabled", false);
